#!/usr/bin/env python3
# coding: utf-8

__author__ = 'torico'
__version__ = '0.4.0'
__license__ = 'BSD'
